yorkfit function, and computes the corresponding isochron
age, including decay constant uncertainties.
isochron(x, ...)
"isochron"(x, xlim = NA, ylim = NA, alpha = 0.05, sigdig = 2, show.numbers = FALSE, ellipse.col = rgb(0, 1, 0, 0.5), line.col = "red", lwd = 2, title = TRUE, ...)
"isochron"(x, xlim = NA, ylim = NA, alpha = 0.05, sigdig = sigdig, show.numbers = FALSE, ellipse.col = rgb(0, 1, 0, 0.5), inverse = TRUE, line.col = "red", lwd = 2, plot = TRUE, ...)X: the x-variable
Y: the y-variable
sX: the standard error of X
sY: the standard error of Y
rXY: the correlation coefficient of X and Y
OR an object of class ArAr
TRUE, plots $^{36}$Ar/$^{40}$Ar
vs. $^{39}$Ar/$^{40}$Ar. If FALSE, plots
$^{40}$Ar/$^{36}$Ar vs. $^{39}$Ar/$^{36}$Ar.FALSE, suppresses the graphical outputplot=FALSE, returns a list with the following items:a: the intercept of the straight line fit and its standard errorb: the slope of the fit and its standard errory0: the atmospheric $^{40}$Ar/$^{36}$Ar ratio and its standard errorage: the $^{40}$Ar/$^{39}$Ar age and its standard error
data(examples)
isochron(examples$ArAr)
Run the code above in your browser using DataLab